from setuptools import setup, find_packages
import os

with open(os.path.join(os.path.dirname(__file__), 'README.md'), encoding='utf-8') as f:
    long_description = f.read()

setup(
    name='anuastra',
    version='1.0.2',
    description='Official Python SDK for the Aṇu Astra Virtual Quantum Processor and PQC API',
    long_description=long_description,
    long_description_content_type='text/markdown',
    author='Aṇu Astra',
    url='https://astra.cryptopix.in',
    packages=find_packages(),
    python_requires='>=3.8',
    install_requires=[
        'requests>=2.25.1',
        'fips203>=0.4.3'
    ],
    classifiers=[
        'Development Status :: 5 - Production/Stable',
        'Intended Audience :: Developers',
        'Intended Audience :: Science/Research',
        'Topic :: Scientific/Engineering :: Physics',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.8',
        'Programming Language :: Python :: 3.9',
        'Programming Language :: Python :: 3.10',
        'Programming Language :: Python :: 3.11',
        'License :: OSI Approved :: MIT License',
        'Operating System :: OS Independent',
    ]
)
